@@ -1,3 +1,27 @@
+#' Print HTML Elements
+#' 
+#' Use this function to output HTML code for use in R Markdown documents
+#' or otherwise.
+#' 
+#' @param ... A set of HTML tag functions. See examples for details.
+#' @param file Location to output the generated HTML.
+#' @export
+#' @seealso
+#' \code{\link{makeHTMLTag}}, for making your own tags.
+#' @examples
+#' html(
+#'   h1("Welcome!"),
+#'   div(class="header", table( tr( td("nested elements are ok") ) ) ),
+#'   footer(class="foot", "HTML5 footer")
+#'   )
+html <- function(..., file="") {
+  dotArgs <- match.call(expand.dots=FALSE)$`...`
+  for( item in dotArgs ) {
+    print( eval( item, envir=.html ), file=file )
+    cat( "\n", file=file )
+  }
+}
+
 #' Print kHTML Objects
 #' 
 #' By default, we \code{cat} out kHTML objects as we typically
@@ -5,11 +29,10 @@
 #' printing of items in the environment \code{html}.
 #' @param ... a set of kHTML objects (strings).
 #' @method print kHTML
+#' @S3method print kHTML
 #' @seealso \code{\link{html}}
-#' @export
 #' @examples
-#' data(html)
-#' html$br()
+#' .html$br()
 print.kHTML <- function(...) {
   cat( ... )
 }
@@ -26,7 +49,7 @@ print.kHTML <- function(...) {
 #' 'data', which is generated for a \code{p} HTML tag.
 #' 
 #' @export
-#' @param tag the HTML tag to use
+#' @param tag the HTML tag to use.
 #' @param ... a collection of named and unnamed arguments;
 #'  named arguments are parsed as attributes of the tag,
 #'  unnamed arguments are pasted together into the inner data of the tag.
@@ -83,60 +106,15 @@ makeHTMLTag <- function(tag, ...) {
   
 }
 
-#' Attach Common, Non-Masking HTML Functions
-#' 
-#' Calling this function will attach HTML tagging functions that 
-#' do not mask any functions available in the 'base' R packages.
-#' 
-#' @seealso \code{\link{detachHTML}}
-#' @export
-attachHTML <- function() {
-  
-  if( ".html.sub" %in% search() ) {
-    warning("HTML functions already attached!")
-    invisible()
-  } else {
-    data("html")
-    myFuns <- c(
-      paste( sep="", "h", 1:6),
-      "tr", "td", "th", "ul", "ol", "li", "p", "span", "br", "strong", "em", "a",
-      "hr", "div", "link", "script", "pre"
-    )
-    .html.sub <- new.env()
-    for( fun in myFuns ) {
-      assign( fun, get(fun, envir=get("html")), envir=.html.sub )
-    }
-    
-    attach(.html.sub)
-  }
-  
-}
-
-#' Detach Common, Non-Masking HTML Functions
-#' 
-#' Calling this function will detach the environment generated by
-#' \code{attachHTML()}.
-#' 
-#' @seealso \code{\link{attachHTML}}
-#' @export
-detachHTML <- function() {
-  
-  if( ".html.sub" %in% search() ) {
-    detach(".html.sub")
-  } else {
-    stop("HTML functions not attached.")
-  }  
-}
-
 # Generate HTML tag environment
 # 
 # Generates the environment used for the HTML utility functions. Included
 # as means of documentation for where the HTML utility functions come from.
-# html <- new.env()
+# .html <- new.env()
 # html_tags <- scan( what=character(), sep="\n", strip.white=TRUE,
-#                    "./data/html.txt" )
-# tags <- gsub( "(<)(.*?)(>)", "\\2", html_tags, perl=TRUE )
+#                 "./data/html.txt" )
+# tags <- sort( gsub( "(<)(.*?)(>)", "\\2", html_tags, perl=TRUE ) )
 # for( tag in tags ) {
-#   assign( tag, makeHTMLTag(tag), envir=html )
+# assign( tag, makeHTMLTag(tag), envir=.html )
 # }
-# save( html, file=paste( sep="",  getwd(), "/data/html.rda" ) )
\ No newline at end of file
+# save( .html, file=paste( sep="",  getwd(), "/data/html.rda" ) )
